@@ -1,6 +1,6 @@
 ;;; examples/nyacc/lang/c99/ffi-help-cd.scm
 
-;; Copyright (C) 2016-2024 Matthew Wette
+;; Copyright (C) 2016-2025 Matthew Wette
 ;;
 ;; This library is free software; you can redistribute it and/or
 ;; modify it under the terms of the GNU Lesser General Public
@@ -63,7 +63,7 @@
   #:use-module ((nyacc lex) #:select (cnumstr->scm))
   #:use-module ((nyacc util) #:select (ugly-print))
   #:re-export (*nyacc-version*)
-  #:version (2 02 4))
+  #:version (2 01 5))
 
 ;; maybe change to a record-type
 (define *options* (make-parameter '()))
@@ -72,7 +72,7 @@
 (define *echo-decls* (make-parameter #f)) ; add echo-decls code for debugging
 
 (define *prefix* (make-parameter "")) ; name prefix (e.g., prefix-syms)
-(define *renamer* (make-parameter identity)) ; renamer from ffi-module
+(define *renamer* (make-parameter (lambda (n c) n))) ; renamer from ffi-module
 
 (define *udict* (make-parameter '()))	   ; udecl dict
 (define *ddict* (make-parameter '()))	   ; cpp-def based dict
@@ -571,6 +571,8 @@
       (`((union-def (ident ,name) ,field-list))
        (cnvt `((union-def ,field-list))))
 
+      (`((function-returning . ,_0) . ,_1) ''*) ;; alias for ptr-to ftn
+
       (otherwise
        (fherr "mtail->ffi-decl missed:\n~A" (ppstr mtail)))))
 
@@ -623,6 +625,8 @@
                   `(unwrap-pointer ,mname (cpointer (cfunction ,pr ,pc))))))))
          (`((pointer-to) . ,_1)
           `(unwrap-pointer ,mname))))
+      (`(function-returning . ,_0)
+       (unwrap-mdecl (cons (md-label mdecl) (cons '(pointer-to) mtail))))
       (`(enum-def (ident ,name) ,_1)
        (cond
 	((dmem? (w/enum name) defined)
@@ -1196,7 +1200,7 @@
                       (delay
                         (make-cdata ,name* (foreign-pointer-search ,name)))))
 	        (case-lambda
-	          (() (cdata-ref (force obj) '*))
+	          (() (cdata-sel (force obj) '*))
 	          ((arg) (cdata-set! (force obj) '* arg)))))))))
 
      ((memq 'const sspec)
@@ -1508,7 +1512,7 @@
           (use-modules (nyacc lang c99 ffi-help))
           (load-include-file \"cairo.h\" #:pkg-config \"cairo\")"
   (parameterize ((*options* '()) (*defined* '())
-		 (*renamer* identity) (*errmsgs* '())
+		 (*renamer* (lambda (n c) n)) (*errmsgs* '())
 		 (*prefix* "") (*mport* #t) (*udict* '()))
     (let* ((attrs (acons 'include (list filename) '()))
 	   (attrs (if pkg-config (acons 'pkg-config pkg-config attrs) attrs))
@@ -1620,7 +1624,7 @@
 ;; @end deffn
 (define* (compile-ffi-file filename #:optional (options '()))
   (parameterize ((*options* options) (*defined* '())
-		 (*renamer* identity) (*errmsgs* '()) (*prefix* "")
+		 (*renamer* (lambda (n c) n)) (*errmsgs* '()) (*prefix* "")
 		 (*mport* #t) (*udict* '()) (*ddict* '()))
     (if (not (access? filename R_OK))
 	(fherr "ERROR: not found: ~S" filename))
